import React, { Component } from "react";
import Taro from "@tarojs/taro";
import { View, Button, } from '@tarojs/components'
import { AtRadio, AtInput, AtModal, AtModalHeader, AtModalContent, AtModalAction } from "taro-ui";
import { accountList, nonBusiness } from '../../utils/tools/config';
import { creatOrder } from '../../utils/servers/servers';
import './index.less';

import "taro-ui/dist/style/components/icon.scss";
import "taro-ui/dist/style/components/button.scss";
import "taro-ui/dist/style/components/radio.scss";

class Select extends Component {
  constructor(props) {
    super(props);
    this.state = {
      type: -1,
      other: "",
      noType: -1,
      others: "",
      popup: false,
    };
  }

  componentDidMount() {
    const { type, other, noType, others } = this.props
    this.setState({
      type,
      other,
      noType,
      others,
    })
  }

  handleChange(e) {
    this.setState({
      type: e,
      popup: e == 2 ? true : false
    })
  }

  onInputChange(e) {
    this.setState({
      other: e,
    })
  }

  onNoChange(e) {
    this.setState({
      noType: e
    })
  }

  onNoInputChange(e) {
    this.setState({
      others: e
    })
  }

  creatOrder() {
    const { prid, onClose } = this.props
    const { type, other, noType, others } = this.state
    if (type == 2) {
      if (noType == -1) {
        Taro.showToast({
          title: '非业务报销需选择二级分类',
          icon: 'none'
        })
        return
      }
    }
    creatOrder({
      prid,
      type,
      typeOther: other,
      secondaryType: type == 2 ? noType : undefined,
      secondaryTypeOther: others,
    }).then(v => {
      if (v.error.length === 0) {
        onClose()
        Taro.redirectTo({
          url: '/pages/drafts/index?id=' + v.data
        })
      } else {
        Taro.showToast({ title: v.error[0].message, icon: 'none' })
      }
    }).catch(() => {
      Taro.showToast({
        title: '系统错误,请稍后再试',
        icon: 'none'
      })
    })
  }


  render() {
    const { visible = "", onClose, noPost = false, onOk } = this.props
    const { type, other, noType, others, popup } = this.state
    return (
      <AtModal
        isOpened={visible != ""}
        closeOnClickOverlay={false}
      >
        <AtModalHeader>请选择报销类型</AtModalHeader>
        <AtModalContent>
          {visible != "" &&
            <View className="rlist">
              <AtRadio
                options={accountList}
                value={type}
                onClick={this.handleChange.bind(this)}
              />
              {type == 0 &&
                <AtInput
                  name='other'
                  type='text'
                  placeholder='请填写明细'
                  value={other}
                  onChange={this.onInputChange.bind(this)}
                />}
              {(type == 2) && popup &&
                <AtModal
                  isOpened={(type == 2) && popup}
                  closeOnClickOverlay={false}
                >
                  <AtModalContent>
                    <View className="rlist">
                      <AtRadio
                        options={nonBusiness}
                        value={noType}
                        onClick={this.onNoChange.bind(this)}
                      />
                      {noType == 0 &&
                        <AtInput
                          name='others'
                          type='text'
                          placeholder='请填写明细'
                          value={others}
                          onChange={this.onNoInputChange.bind(this)}
                        />}
                    </View>
                  </AtModalContent>
                  <AtModalAction>
                    <Button onClick={() => {
                      this.setState({
                        popup: false
                      })
                    }}>上一步</Button>
                    <Button onClick={() => {
                      if (noType == -1) {
                        Taro.showToast({
                          title: '请选择费用类型',
                          icon: 'none'
                        })
                      } else if (noType == 0 && !others) {
                        Taro.showToast({
                          title: '请填写其他明细',
                          icon: 'none'
                        })
                      } else {
                        this.setState({
                          popup: false
                        })
                      }
                    }}>确定</Button>
                  </AtModalAction>
                </AtModal>}
            </View>}
        </AtModalContent>
        <AtModalAction>
          <Button onClick={onClose}>取消</Button>
          <Button onClick={() => {
            if (type == -1) {
              Taro.showToast({
                title: '请选择报销费用类型',
                icon: 'none'
              })
            } else if (type == 0 && !other) {
              Taro.showToast({
                title: '请填写其他明细',
                icon: 'none'
              })
            } else {
              noPost
                ? this.creatOrder()
                : onOk(type, other, noType, others)
            }
          }}>确定</Button>
        </AtModalAction>
      </AtModal>
    )
  }
}

export default Select;
